#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library
import base64

# import interfaces
from pyams_content.component.extfile.interfaces import IExtFileContainerTarget, IExtFileContainer
from pyams_content_es.interfaces import IDocumentIndexInfo

# import packages
from pyams_utils.adapter import adapter_config


@adapter_config(name='extfile', context=IExtFileContainerTarget, provides=IDocumentIndexInfo)
def ExtFileContainerTargetIndexInfo(content):
    """External files index info"""
    result = []
    for extfile in IExtFileContainer(content).values():
        extfile_index = {'title': extfile.title,
                         'description': extfile.description,
                         'data': {}}
        for lang, data in extfile.data.items():
            if data.content_type.startswith(b'image/') or \
               data.content_type.startswith(b'audio/') or \
               data.content_type.startswith(b'video/'):
                continue
            extfile_index['data'][lang] = {
                '_content_type': data.content_type.decode(),
                '_name': data.filename,
                '_language': lang,
                '_content': base64.encodebytes(data.data).decode()
            }
        result.append(extfile_index)
    return {'extfile': result}
